@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-Created on Tue Mar 31 12:50:44 2020
+Created on Tue Mar 31 2020 12:50:44
 
 """
 import os
@@ -18,19 +18,13 @@ from soloman.fps_clocks import *
 
 def register():
 
-    directory = __file__.replace('\\soloman\\__init__.py', '')
-    if 'QML2_IMPORT_PATH' in os.environ:
-        os.environ['QML2_IMPORT_PATH'] += ';' + directory
-    else:
-        os.environ['QML2_IMPORT_PATH'] = directory
-
     # Delete the contents of our Temp folder
     path = os.path.join(os.environ['TEMP'], 'soloman', 'converts')
     if os.path.exists(path):
         os.system('RD "' + path + '" /S /Q')
 
-    qmlRegisterType(QAudio, 'soloman', 2, 2, 'SAudio')
-    qmlRegisterType(QVideo, 'soloman', 2, 2, 'QVideo')
+    qmlRegisterType(QAudio, 'soloman', 2, 4, 'SAudio')
+    qmlRegisterType(QVideo, 'soloman', 2, 4, 'QVideo')
 
 
 register()
